aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/gnome-month-item.h
diff options
context:
space:
mode:
Diffstat (limited to 'calendar/gnome-month-item.h')
-rw-r--r--calendar/gnome-month-item.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/calendar/gnome-month-item.h b/calendar/gnome-month-item.h
index 2260186c6d..f6523aff94 100644
--- a/calendar/gnome-month-item.h
+++ b/calendar/gnome-month-item.h
@@ -36,13 +36,16 @@ struct _GnomeMonthItem {
double width, height; /* Size of calendar */
GtkAnchorType anchor; /* Anchor side for calendar */
- double padding; /* Padding to use between division lines and text */
+ double head_padding; /* Padding to use between heading lines and text */
+ double day_padding; /* Padding to use between day number lines and text */
char *day_names[7]; /* Names to use for the day labels, starting from Sunday */
double head_height; /* Height of the headings row */
GtkAnchorType head_anchor; /* Anchor side for the heading labels */
+ GtkAnchorType day_anchor; /* Anchor side for the day number labels */
+
GnomeCanvasItem **items; /* All the items that make up the calendar */
int start_on_monday : 1; /* Start the week on Monday? If false, then start from Sunday */